==> klayout_0.28.5.orig.tar.gz: klayout-0.28.5/scripts/mkqtdecl5/QtCore/allofqt.cpp <==
#include "QtCore/QAbstractAnimation"
#include "QtCore/QAbstractEventDispatcher"
#include "QtCore/QAbstractItemModel"
#include "QtCore/QAbstractListModel"
#include "QtCore/QAbstractNativeEventFilter"
#include "QtCore/QAbstractProxyModel"
#include "QtCore/QAbstractState"
#include "QtCore/QAbstractTableModel"
#include "QtCore/QAbstractTransition"
#include "QtCore/QAnimationDriver"
#include "QtCore/QAnimationGroup"
#include "QtCore/QArgument"
#include "QtCore/QArrayData"
#include "QtCore/QArrayDataPointer"
#include "QtCore/QArrayDataPointerRef"
#include "QtCore/QAssociativeIterable"
#include "QtCore/QAtomicInt"
#include "QtCore/QAtomicInteger"
#include "QtCore/QAtomicPointer"
#include "QtCore/QBasicMutex"
#include "QtCore/QBasicTimer"
#include "QtCore/QBBSystemLocaleData"
#include "QtCore/QBitArray"
#include "QtCore/QBitRef"
#include "QtCore/QBuffer"
#include "QtCore/QByteArray"
#include "QtCore/QByteArrayData"
#include "QtCore/QByteArrayDataPtr"
#include "QtCore/QByteArrayList"
#include "QtCore/QByteArrayListIterator"
#include "QtCore/QByteArrayMatcher"
#include "QtCore/QByteRef"
#include "QtCore/QCache"
#include "QtCore/QChar"
#include "QtCore/QCharRef"
#include "QtCore/QChildEvent"
#include "QtCore/QCollator"
#include "QtCore/QCollatorSortKey"
#include "QtCore/QCommandLineOption"
#include "QtCore/QCommandLineParser"
#include "QtCore/QContiguousCache"
#include "QtCore/QContiguousCacheData"
#include "QtCore/QContiguousCacheTypedData"
#include "QtCore/QCoreApplication"
#include "QtCore/QCryptographicHash"
#include "QtCore/QDataStream"
#include "QtCore/QDate"
#include "QtCore/QDateTime"
#include "QtCore/QDebug"
#include "QtCore/QDebugStateSaver"
#include "QtCore/QDeferredDeleteEvent"
#include "QtCore/QDir"
#include "QtCore/QDirIterator"
#include "QtCore/QDynamicPropertyChangeEvent"
#include "QtCore/QEasingCurve"
#include "QtCore/QElapsedTimer"
#include "QtCore/QEnableSharedFromThis"
#include "QtCore/QEvent"
#include "QtCore/QEventLoop"
#include "QtCore/QEventLoopLocker"
#include "QtCore/QEventTransition"
#include "QtCore/QException"
#include "QtCore/QExplicitlySharedDataPointer"
#include "QtCore/QFactoryInterface"
#include "QtCore/QFile"
#include "QtCore/QFileDevice"
#include "QtCore/QFileInfo"
#include "QtCore/QFileInfoList"
#include "QtCore/QFileSelector"
#include "QtCore/QFileSystemWatcher"
#include "QtCore/QFinalState"
#include "QtCore/QFlag"
#include "QtCore/QFlags"
#include "QtCore/QForeachContainer"
#include "QtCore/QFunctionPointer"
#include "QtCore/QFuture"
#include "QtCore/QFutureInterface"
#include "QtCore/QFutureInterfaceBase"
#include "QtCore/QFutureIterator"
#include "QtCore/QFutureSynchronizer"
#include "QtCore/QFutureWatcher"
#include "QtCore/QFutureWatcherBase"
#include "QtCore/QGenericArgument"
#include "QtCore/QGenericReturnArgument"
#include "QtCore/QGlobalStatic"
#include "QtCore/QHash"
#include "QtCore/QHashData"
#include "QtCore/QHashDummyValue"
#include "QtCore/QHashIterator"
#include "QtCore/QHashNode"
#include "QtCore/QHistoryState"
#include "QtCore/QIdentityProxyModel"
#include "QtCore/QIncompatibleFlag"
#include "QtCore/QIntegerForSize"
#include "QtCore/QInternal"
#include "QtCore/QIODevice"
#include "QtCore/QItemSelection"
#include "QtCore/QItemSelectionModel"
#include "QtCore/QItemSelectionRange"
#include "QtCore/QJsonArray"
#include "QtCore/QJsonDocument"
#include "QtCore/QJsonObject"
#include "QtCore/QJsonParseError"
#include "QtCore/QJsonValue"
#include "QtCore/QJsonValuePtr"
#include "QtCore/QJsonValueRef"
#include "QtCore/QJsonValueRefPtr"
#include "QtCore/QLatin1Char"
#include "QtCore/QLatin1Literal"
#include "QtCore/QLatin1String"
#include "QtCore/QLibrary"
#include "QtCore/QLibraryInfo"
#include "QtCore/QLine"
#include "QtCore/QLineF"
#include "QtCore/QLinkedList"
#include "QtCore/QLinkedListData"
#include "QtCore/QLinkedListIterator"
#include "QtCore/QLinkedListNode"
#include "QtCore/QList"
#include "QtCore/QListData"
#include "QtCore/QListIterator"
#include "QtCore/QListSpecialMethods"
#include "QtCore/QLocale"
#include "QtCore/QLockFile"
#include "QtCore/QLoggingCategory"
#include "QtCore/QMap"
#include "QtCore/QMapData"
#include "QtCore/QMapDataBase"
#include "QtCore/QMapIterator"
#include "QtCore/QMapNode"
#include "QtCore/QMapNodeBase"
#include "QtCore/QMargins"
#include "QtCore/QMarginsF"
#include "QtCore/QMessageAuthenticationCode"
#include "QtCore/QMessageLogContext"
#include "QtCore/QMessageLogger"
#include "QtCore/QMetaClassInfo"
#include "QtCore/QMetaEnum"
#include "QtCore/QMetaMethod"
#include "QtCore/QMetaObject"
#include "QtCore/QMetaProperty"
#include "QtCore/QMetaType"
#include "QtCore/QMetaTypeId"
#include "QtCore/QMetaTypeId2"
#include "QtCore/QMetaTypeIdQObject"
#include "QtCore/QMimeData"
#include "QtCore/QMimeDatabase"
#include "QtCore/QMimeType"
#include "QtCore/QModelIndex"
#include "QtCore/QModelIndexList"
#include "QtCore/QMultiHash"
#include "QtCore/QMultiMap"
#include "QtCore/QMutableByteArrayListIterator"
#include "QtCore/QMutableFutureIterator"
#include "QtCore/QMutableHashIterator"
#include "QtCore/QMutableLinkedListIterator"
#include "QtCore/QMutableListIterator"
#include "QtCore/QMutableMapIterator"
#include "QtCore/QMutableSetIterator"
#include "QtCore/QMutableStringListIterator"
#include "QtCore/QMutableVectorIterator"
#include "QtCore/QMutex"
#include "QtCore/QMutexLocker"
#include "QtCore/QNoDebug"
#include "QtCore/QObject"
#include "QtCore/QObjectCleanupHandler"
#include "QtCore/QObjectData"
#include "QtCore/QObjectList"
#include "QtCore/QObjectUserData"
#include "QtCore/QPair"
#include "QtCore/QParallelAnimationGroup"
#include "QtCore/QPauseAnimation"
#include "QtCore/QPersistentModelIndex"
#include "QtCore/Q_PID"
#include "QtCore/QPluginLoader"
#include "QtCore/QPoint"
#include "QtCore/QPointer"
#include "QtCore/QPointF"
#include "QtCore/QProcess"
#include "QtCore/QProcessEnvironment"
#include "QtCore/QPropertyAnimation"
#include "QtCore/QQueue"
#include "QtCore/QReadLocker"
#include "QtCore/QReadWriteLock"
#include "QtCore/QRect"
#include "QtCore/QRectF"
#include "QtCore/QRegExp"
#include "QtCore/QRegularExpression"
#include "QtCore/QRegularExpressionMatch"
#include "QtCore/QRegularExpressionMatchIterator"
#include "QtCore/QResource"
#include "QtCore/QReturnArgument"
#include "QtCore/QRunnable"
#include "QtCore/QSaveFile"
#include "QtCore/QScopedArrayPointer"
#include "QtCore/QScopedPointer"
#include "QtCore/QScopedPointerArrayDeleter"
#include "QtCore/QScopedPointerDeleteLater"
#include "QtCore/QScopedPointerDeleter"
#include "QtCore/QScopedPointerObjectDeleteLater"
#include "QtCore/QScopedPointerPodDeleter"
#include "QtCore/QScopedValueRollback"
#include "QtCore/QSemaphore"
#include "QtCore/QSequentialAnimationGroup"
#include "QtCore/QSequentialIterable"
#include "QtCore/QSet"
#include "QtCore/QSetIterator"
#include "QtCore/QSettings"
#include "QtCore/QSharedData"
#include "QtCore/QSharedDataPointer"
#include "QtCore/QSharedMemory"
#include "QtCore/QSharedPointer"
#include "QtCore/QSignalBlocker"
#include "QtCore/QSignalMapper"
#include "QtCore/QSignalTransition"
#include "QtCore/QSize"
#include "QtCore/QSizeF"
#include "QtCore/QSocketNotifier"
#include "QtCore/QSortFilterProxyModel"
#include "QtCore/QStack"
#include "QtCore/QStandardPaths"
#include "QtCore/QState"
#include "QtCore/QStateMachine"
#include "QtCore/QStaticArrayData"
#include "QtCore/QStaticAssertFailure"
#include "QtCore/QStaticByteArrayData"
#include "QtCore/QStaticPlugin"
#include "QtCore/QStaticStringData"
#include "QtCore/QStorageInfo"
#include "QtCore/QString"
#include "QtCore/QStringBuilder"
#include "QtCore/QStringData"
#include "QtCore/QStringDataPtr"
#include "QtCore/QStringList"
#include "QtCore/QStringListIterator"
#include "QtCore/QStringListModel"
#include "QtCore/QStringMatcher"
#include "QtCore/QStringRef"
#include "QtCore/QSysInfo"
#include "QtCore/QSystemSemaphore"
#include "QtCore/Qt"
#include "QtCore/QtAlgorithms"
#include "QtCore/QtCleanUpFunction"
#include "QtCore/QtConfig"
#include "QtCore/QtContainerFwd"
#include "QtCore/QtCore"
#include "QtCore/QtCoreDepends"
#include "QtCore/QtCoreVersion"
#include "QtCore/QtDebug"
#include "QtCore/QTemporaryDir"
#include "QtCore/QTemporaryFile"
#include "QtCore/QtEndian"
#include "QtCore/QTextBoundaryFinder"
#include "QtCore/QTextCodec"
#include "QtCore/QTextDecoder"
#include "QtCore/QTextEncoder"
#include "QtCore/QTextStream"
#include "QtCore/QTextStreamFunction"
#include "QtCore/QTextStreamManipulator"
#include "QtCore/QtGlobal"
#include "QtCore/QThread"
#include "QtCore/QThreadPool"
#include "QtCore/QThreadStorage"
#include "QtCore/QThreadStorageData"
#include "QtCore/QTime"
#include "QtCore/QTimeLine"
#include "QtCore/QTimer"
#include "QtCore/QTimerEvent"
#include "QtCore/QTimeZone"
#include "QtCore/QtMath"
#include "QtCore/QtMessageHandler"
#include "QtCore/QtMsgHandler"
#include "QtCore/QtNumeric"
#include "QtCore/QtPlugin"
#include "QtCore/QtPluginInstanceFunction"
#include "QtCore/QtPluginMetaDataFunction"
#include "QtCore/QTranslator"
#include "QtCore/QTypeInfo"
#include "QtCore/QTypeInfoMerger"
#include "QtCore/QUnhandledException"
#include "QtCore/QUrl"
#include "QtCore/QUrlQuery"
#include "QtCore/QUrlTwoFlags"
#include "QtCore/QUuid"
#include "QtCore/QVariant"
#include "QtCore/QVariantAnimation"
#include "QtCore/QVariantComparisonHelper"
#include "QtCore/QVariantHash"
#include "QtCore/QVariantList"
#include "QtCore/QVariantMap"
#include "QtCore/QVarLengthArray"
#include "QtCore/QVector"
#include "QtCore/QVectorIterator"
#include "QtCore/QWaitCondition"
#include "QtCore/QWeakPointer"
#include "QtCore/QWinEventNotifier"
#include "QtCore/QWriteLocker"
#include "QtCore/QXmlStreamAttribute"
#include "QtCore/QXmlStreamAttributes"
#include "QtCore/QXmlStreamEntityDeclaration"
#include "QtCore/QXmlStreamEntityDeclarations"
#include "QtCore/QXmlStreamEntityResolver"
#include "QtCore/QXmlStreamNamespaceDeclaration"
#include "QtCore/QXmlStreamNamespaceDeclarations"
#include "QtCore/QXmlStreamNotationDeclaration"
#include "QtCore/QXmlStreamNotationDeclarations"
#include "QtCore/QXmlStreamReader"
#include "QtCore/QXmlStreamStringRef"
#include "QtCore/QXmlStreamWriter"

==> klayout-0.30.4.tar.gz: klayout-0.30.4/scripts/mkqtdecl5/QtCore/allofqt.cpp <==
#include "QtCore/QAbstractAnimation"
#include "QtCore/QAbstractEventDispatcher"
#include "QtCore/QAbstractItemModel"
#include "QtCore/QAbstractListModel"
#include "QtCore/QAbstractNativeEventFilter"
#include "QtCore/QAbstractProxyModel"
#include "QtCore/QAbstractState"
#include "QtCore/QAbstractTableModel"
#include "QtCore/QAbstractTransition"
#include "QtCore/QAnimationDriver"
#include "QtCore/QAnimationGroup"
#include "QtCore/QArgument"
#include "QtCore/QArrayData"
#include "QtCore/QArrayDataPointer"
#include "QtCore/QArrayDataPointerRef"
#include "QtCore/QAssociativeIterable"
#include "QtCore/QAtomicInt"
#include "QtCore/QAtomicInteger"
#include "QtCore/QAtomicPointer"
#include "QtCore/QBasicMutex"
#include "QtCore/QBasicTimer"
#include "QtCore/QBEInteger"
#include "QtCore/QBigEndianStorageType"
#include "QtCore/QBitArray"
#include "QtCore/QBitRef"
#include "QtCore/QBuffer"
#include "QtCore/QByteArray"
#include "QtCore/QByteArrayData"
#include "QtCore/QByteArrayDataPtr"
#include "QtCore/QByteArrayList"
#include "QtCore/QByteArrayListIterator"
#include "QtCore/QByteArrayMatcher"
#include "QtCore/QByteRef"
#include "QtCore/QCache"
#include "QtCore/QCborArray"
#include "QtCore/QCborError"
#include "QtCore/QCborMap"
#include "QtCore/QCborParserError"
#include "QtCore/QCborStreamReader"
#include "QtCore/QCborStreamWriter"
#include "QtCore/QCborValue"
#include "QtCore/QCborValueRef"
#include "QtCore/QChar"
#include "QtCore/QCharRef"
#include "QtCore/QChildEvent"
#include "QtCore/QCollator"
#include "QtCore/QCollatorSortKey"
#include "QtCore/QCommandLineOption"
#include "QtCore/QCommandLineParser"
// #include "QtCore/QConstOverload"
#include "QtCore/QContiguousCache"
#include "QtCore/QContiguousCacheData"
#include "QtCore/QContiguousCacheTypedData"
#include "QtCore/QCoreApplication"
#include "QtCore/QCryptographicHash"
#include "QtCore/QDataStream"
#include "QtCore/QDate"
#include "QtCore/QDateTime"
#include "QtCore/QDeadlineTimer"
#include "QtCore/QDebug"
#include "QtCore/QDebugStateSaver"
#include "QtCore/QDeferredDeleteEvent"
#include "QtCore/QDir"
#include "QtCore/QDirIterator"
#include "QtCore/QDynamicPropertyChangeEvent"
#include "QtCore/QEasingCurve"
#include "QtCore/QElapsedTimer"
#include "QtCore/QEnableSharedFromThis"
#include "QtCore/QEvent"
#include "QtCore/QEventLoop"
#include "QtCore/QEventLoopLocker"
#include "QtCore/QEventTransition"
#include "QtCore/QException"
#include "QtCore/QExplicitlySharedDataPointer"
#include "QtCore/QFactoryInterface"
#include "QtCore/QFile"
#include "QtCore/QFileDevice"
#include "QtCore/QFileInfo"
#include "QtCore/QFileInfoList"
#include "QtCore/QFileSelector"
#include "QtCore/QFileSystemWatcher"
#include "QtCore/QFinalState"
#include "QtCore/QFlag"
#include "QtCore/QFlags"
#include "QtCore/QFloat16"
#include "QtCore/QFunctionPointer"
#include "QtCore/QFuture"
#include "QtCore/QFutureInterface"
#include "QtCore/QFutureInterfaceBase"
#include "QtCore/QFutureIterator"
#include "QtCore/QFutureSynchronizer"
#include "QtCore/QFutureWatcher"
#include "QtCore/QFutureWatcherBase"
#include "QtCore/QGenericArgument"
#include "QtCore/QGenericReturnArgument"
#include "QtCore/QGlobalStatic"
#include "QtCore/QHash"
#include "QtCore/QHashData"
#include "QtCore/QHashDummyValue"
#include "QtCore/QHashFunctions"
#include "QtCore/QHashIterator"
#include "QtCore/QHashNode"
#include "QtCore/QHistoryState"
#include "QtCore/QIdentityProxyModel"
#include "QtCore/QIncompatibleFlag"
#include "QtCore/QIntegerForSize"
#include "QtCore/QInternal"
#include "QtCore/QIODevice"
#include "QtCore/QItemSelection"
#include "QtCore/QItemSelectionModel"
#include "QtCore/QItemSelectionRange"
#include "QtCore/QJsonArray"
#include "QtCore/QJsonDocument"
#include "QtCore/QJsonObject"
#include "QtCore/QJsonParseError"
#include "QtCore/QJsonValue"
#include "QtCore/QJsonValuePtr"
#include "QtCore/QJsonValueRef"
#include "QtCore/QJsonValueRefPtr"
// #include "QtCore/QKeyValueIterator"
#include "QtCore/QLatin1Char"
#include "QtCore/QLatin1Literal"
#include "QtCore/QLatin1String"
#include "QtCore/QLEInteger"
#include "QtCore/QLibrary"
#include "QtCore/QLibraryInfo"
#include "QtCore/QLine"
#include "QtCore/QLineF"
#include "QtCore/QLinkedList"
#include "QtCore/QLinkedListData"
#include "QtCore/QLinkedListIterator"
#include "QtCore/QLinkedListNode"
#include "QtCore/QList"
#include "QtCore/QListData"
#include "QtCore/QListIterator"
#include "QtCore/QListSpecialMethods"
#include "QtCore/QLittleEndianStorageType"
#include "QtCore/QLocale"
#include "QtCore/QLockFile"
#include "QtCore/QLoggingCategory"
#include "QtCore/QMap"
#include "QtCore/QMapData"
#include "QtCore/QMapDataBase"
#include "QtCore/QMapIterator"
#include "QtCore/QMapNode"
#include "QtCore/QMapNodeBase"
#include "QtCore/QMargins"
#include "QtCore/QMarginsF"
#include "QtCore/QMessageAuthenticationCode"
#include "QtCore/QMessageLogContext"
#include "QtCore/QMessageLogger"
#include "QtCore/QMetaClassInfo"
#include "QtCore/QMetaEnum"
#include "QtCore/QMetaMethod"
#include "QtCore/QMetaObject"
#include "QtCore/QMetaProperty"
#include "QtCore/QMetaType"
#include "QtCore/QMimeData"
#include "QtCore/QMimeDatabase"
#include "QtCore/QMimeType"
#include "QtCore/QModelIndex"
#include "QtCore/QModelIndexList"
#include "QtCore/QMultiHash"
#include "QtCore/QMultiMap"
#include "QtCore/QMutableByteArrayListIterator"
#include "QtCore/QMutableFutureIterator"
#include "QtCore/QMutableHashIterator"
#include "QtCore/QMutableLinkedListIterator"
#include "QtCore/QMutableListIterator"
#include "QtCore/QMutableMapIterator"
#include "QtCore/QMutableSetIterator"
#include "QtCore/QMutableStringListIterator"
#include "QtCore/QMutableVectorIterator"
#include "QtCore/QMutex"
#include "QtCore/QMutexLocker"
#include "QtCore/QNoDebug"
// #include "QtCore/QNonConstOverload"
#include "QtCore/QObject"
#include "QtCore/QObjectCleanupHandler"
#include "QtCore/QObjectData"
#include "QtCore/QObjectList"
#include "QtCore/QObjectUserData"
#include "QtCore/QOperatingSystemVersion"
#include "QtCore/QPair"
#include "QtCore/QParallelAnimationGroup"
#include "QtCore/QPauseAnimation"
#include "QtCore/QPersistentModelIndex"
#include "QtCore/Q_PID"
#include "QtCore/QPluginLoader"
#include "QtCore/QPoint"
#include "QtCore/QPointer"
#include "QtCore/QPointF"
#include "QtCore/QProcess"
#include "QtCore/QProcessEnvironment"
#include "QtCore/QPropertyAnimation"
#include "QtCore/QQueue"
#include "QtCore/QRandomGenerator"
#include "QtCore/QRandomGenerator64"
#include "QtCore/QReadLocker"
#include "QtCore/QReadWriteLock"
#include "QtCore/QRect"
#include "QtCore/QRectF"
#include "QtCore/QRegExp"
#include "QtCore/QRegularExpression"
#include "QtCore/QRegularExpressionMatch"
#include "QtCore/QRegularExpressionMatchIterator"
#include "QtCore/QResource"
#include "QtCore/QReturnArgument"
#include "QtCore/QRunnable"
#include "QtCore/QSaveFile"
#include "QtCore/QScopedArrayPointer"
#include "QtCore/QScopedPointer"
#include "QtCore/QScopedPointerArrayDeleter"
#include "QtCore/QScopedPointerDeleteLater"
#include "QtCore/QScopedPointerDeleter"
#include "QtCore/QScopedPointerObjectDeleteLater"
#include "QtCore/QScopedPointerPodDeleter"
#include "QtCore/QScopedValueRollback"
#include "QtCore/QScopeGuard"
// #include "QtCore/Q_SECURITY_ATTRIBUTES"
#include "QtCore/QSemaphore"
#include "QtCore/QSemaphoreReleaser"
#include "QtCore/QSequentialAnimationGroup"
#include "QtCore/QSequentialIterable"
#include "QtCore/QSet"
#include "QtCore/QSetIterator"
#include "QtCore/QSettings"
#include "QtCore/QSharedData"
#include "QtCore/QSharedDataPointer"
#include "QtCore/QSharedMemory"
#include "QtCore/QSharedPointer"
#include "QtCore/QSignalBlocker"
#include "QtCore/QSignalMapper"
#include "QtCore/QSignalTransition"
#include "QtCore/QSize"
#include "QtCore/QSizeF"
#include "QtCore/QSocketNotifier"
#include "QtCore/QSortFilterProxyModel"
#include "QtCore/QSpecialInteger"
#include "QtCore/QStack"
#include "QtCore/QStandardPaths"
// #include "QtCore/Q_STARTUPINFO"
#include "QtCore/QState"
#include "QtCore/QStateMachine"
#include "QtCore/QStaticArrayData"
#include "QtCore/QStaticByteArrayData"
#include "QtCore/QStaticByteArrayMatcherBase"
#include "QtCore/QStaticPlugin"
#include "QtCore/QStaticStringData"
#include "QtCore/QStorageInfo"
#include "QtCore/QString"
#include "QtCore/QStringAlgorithms"
#include "QtCore/QStringBuilder"
#include "QtCore/QStringData"
#include "QtCore/QStringDataPtr"
#include "QtCore/QStringList"
#include "QtCore/QStringListIterator"
#include "QtCore/QStringListModel"
#include "QtCore/QStringLiteral"
#include "QtCore/QStringMatcher"
#include "QtCore/QStringRef"
#include "QtCore/QStringView"
#include "QtCore/QSysInfo"
#include "QtCore/QSystemSemaphore"
#include "QtCore/Qt"
#include "QtCore/QtAlgorithms"
#include "QtCore/QtCborCommon"
#include "QtCore/QtCleanUpFunction"
#include "QtCore/QtConfig"
#include "QtCore/QtContainerFwd"
#include "QtCore/QtCore"
#include "QtCore/QtCoreDepends"
#include "QtCore/QtCoreVersion"
#include "QtCore/QtDebug"
#include "QtCore/QTemporaryDir"
#include "QtCore/QTemporaryFile"
#include "QtCore/QtEndian"
#include "QtCore/QTextBoundaryFinder"
#include "QtCore/QTextCodec"
#include "QtCore/QTextDecoder"
#include "QtCore/QTextEncoder"
#include "QtCore/QTextStream"
#include "QtCore/QTextStreamFunction"
#include "QtCore/QTextStreamManipulator"
#include "QtCore/QtGlobal"
#include "QtCore/QThread"
#include "QtCore/QThreadPool"
#include "QtCore/QThreadStorage"
#include "QtCore/QThreadStorageData"
#include "QtCore/QTime"
#include "QtCore/QTimeLine"
#include "QtCore/QTimer"
#include "QtCore/QTimerEvent"
#include "QtCore/QTimeZone"
#include "QtCore/QtMath"
#include "QtCore/QtMessageHandler"
#include "QtCore/QtMsgHandler"
#include "QtCore/QtNumeric"
#include "QtCore/QtPlugin"
#include "QtCore/QtPluginInstanceFunction"
#include "QtCore/QtPluginMetaDataFunction"
#include "QtCore/QTranslator"
#include "QtCore/QTypeInfo"
#include "QtCore/QTypeInfoMerger"
// #include "QtCore/QTypeInfoQuery"
#include "QtCore/QUnhandledException"
#include "QtCore/QUrl"
#include "QtCore/QUrlQuery"
#include "QtCore/QUrlTwoFlags"
#include "QtCore/QUuid"
#include "QtCore/QVariant"
#include "QtCore/QVariantAnimation"
#include "QtCore/QVariantComparisonHelper"
#include "QtCore/QVariantHash"
#include "QtCore/QVariantList"
#include "QtCore/QVariantMap"
#include "QtCore/QVarLengthArray"
#include "QtCore/QVector"
#include "QtCore/QVectorIterator"
#include "QtCore/QVersionNumber"
#include "QtCore/QWaitCondition"
#include "QtCore/QWeakPointer"
#include "QtCore/QWinEventNotifier"
#include "QtCore/QWriteLocker"
#include "QtCore/QXmlStreamAttribute"
#include "QtCore/QXmlStreamAttributes"
#include "QtCore/QXmlStreamEntityDeclaration"
#include "QtCore/QXmlStreamEntityDeclarations"
#include "QtCore/QXmlStreamEntityResolver"
#include "QtCore/QXmlStreamNamespaceDeclaration"
#include "QtCore/QXmlStreamNamespaceDeclarations"
#include "QtCore/QXmlStreamNotationDeclaration"
#include "QtCore/QXmlStreamNotationDeclarations"
#include "QtCore/QXmlStreamReader"
#include "QtCore/QXmlStreamStringRef"
#include "QtCore/QXmlStreamWriter"
